#!/usr/bin/python3
import statistics
import sys
import json


def load(fname):
    r = {}
    with open(fname) as fp:
        results = json.load(fp)['functions']['memcpy']['results']
    for result in results:
        [r[result['length']]] = result['timings']
    return r


def load_set(fnames):
    r = {}

    times = []
    for fname in fnames:
        times.append(load(fname))

    lengths = set(times[0].keys())
    for t in times[1:]:
        if set(t.keys()) != lengths:
            raise Exception('inconsistent')

    for length in lengths:
        ts = [t[length] for t in times]
        ts.remove(max(ts))
        ts.remove(min(ts))
        r[length] = int(statistics.mean(ts))

    return r


i = 1
while sys.argv[i] != '--':
    i += 1

print('loading first set', sys.argv[1:i-1])
set1 = load_set(sys.argv[1:i-1])
print()
print('loading second set', sys.argv[i+1:])
set2 = load_set(sys.argv[i+1:])
print()


print(" {:>8} | {:>14} | {:>14} | {:>8}".format(
    "length", "before (MiB/s)", "after (MiB/s)", "delta"))
print('|'.join("-"*(i+2) for i in (8, 14, 14, 8)))
for length in sorted(set1.keys()):
    time1_ns = set1[length]
    rate1 = length/(time1_ns/1e9)/1024/1024
    time2_ns = set2[length]
    rate2 = length/(time2_ns/1e9)/1024/1024
    print(" {:8} | {:14.2f} | {:14.2f} | {:7.2f}%".format(
        length, rate1, rate2, 100*(rate2-rate1)/rate1))
